package com.wechi.adweb.bridge.google.analytics.dto.report.data;

import static com.wechi.adweb.bridge.google.analytics.dto.report.ReportConstant.*;

import com.google.analytics.data.v1beta.Row;

import lombok.Builder;
import lombok.Data;

import java.util.List;

/**
 * @author wfansh
 */
@Data
@Builder
public class PagePathViewData implements GAReportDataDTO {

    private String pagePath;

    private double engagementRate;

    private int pageViews;

    private double avgTimeOnPage;

    public static List<PagePathViewData> toReport(
            List<Row> reportRows, List<String> metrics, List<String> dimensions) {
        int indexPagePath = dimensions.indexOf(DIMENSION_PAGE_PATH);
        int indexEngagementRate = metrics.indexOf(METRIC_ENGAGEMENT_RATE);
        int indexPageViews = metrics.indexOf(METRIC_SCREEN_PAGE_VIEWS);
        int indexUserEngagementDuration = metrics.indexOf(METRIC_USER_ENGAGEMENT_DURATION);

        return reportRows.stream()
                .map(
                        row ->
                                PagePathViewData.builder()
                                        .pagePath(row.getDimensionValues(indexPagePath).getValue())
                                        .engagementRate(
                                                Double.parseDouble(
                                                        row.getMetricValues(indexEngagementRate)
                                                                .getValue()))
                                        .pageViews(
                                                Integer.parseInt(
                                                        row.getMetricValues(indexPageViews)
                                                                .getValue()))
                                        .avgTimeOnPage(
                                                Double.parseDouble(
                                                        row.getMetricValues(
                                                                        indexUserEngagementDuration)
                                                                .getValue()))
                                        .build())
                .toList();
    }
}
