package com.wechi.adweb.bridge.google.analytics.dto.report.data;

import static com.wechi.adweb.bridge.google.analytics.dto.report.ReportConstant.*;

import com.google.analytics.data.v1beta.Row;

import lombok.Builder;
import lombok.Data;

import java.util.List;

/**
 * @author wfansh
 */
@Data
@Builder
public class SourceMediaViewData implements GAReportDataDTO {

    private String type;

    private int totalUsers;

    private int newUsers;

    private int sessions;

    private double bounceRate;

    private double avgSessionDuration;

    private double pageViewsPerSession;

    public static List<SourceMediaViewData> toReport(
            List<Row> reportRows, List<String> metrics, List<String> dimensions) {
        int indexType = dimensions.indexOf(DIMENSION_SESSION_SOURCE_MEDIUM);
        int indexTotalUsers = metrics.indexOf(METRIC_TOTAL_USERS);
        int indexNewUsers = metrics.indexOf(METRIC_NEW_USERS);
        int indexSessions = metrics.indexOf(METRIC_SESSIONS);
        int indexBounceRate = metrics.indexOf(METRIC_BOUNCE_RATE);
        int indexAvgSessionDuration = metrics.indexOf(METRIC_AVG_SESSION_DURATION);
        int indexPageViewsPerSession = metrics.indexOf(METRIC_SCREEN_PAGE_VIEWS_PER_SESSION);

        return reportRows.stream()
                .map(
                        row ->
                                SourceMediaViewData.builder()
                                        .type(row.getDimensionValues(indexType).getValue())
                                        .totalUsers(
                                                Integer.parseInt(
                                                        row.getMetricValues(indexTotalUsers)
                                                                .getValue()))
                                        .newUsers(
                                                Integer.parseInt(
                                                        row.getMetricValues(indexNewUsers)
                                                                .getValue()))
                                        .sessions(
                                                Integer.parseInt(
                                                        row.getMetricValues(indexSessions)
                                                                .getValue()))
                                        .bounceRate(
                                                Double.parseDouble(
                                                        row.getMetricValues(indexBounceRate)
                                                                .getValue()))
                                        .avgSessionDuration(
                                                Double.parseDouble(
                                                        row.getMetricValues(indexAvgSessionDuration)
                                                                .getValue()))
                                        .pageViewsPerSession(
                                                Double.parseDouble(
                                                        row.getMetricValues(
                                                                        indexPageViewsPerSession)
                                                                .getValue()))
                                        .build())
                .toList();
    }
}
